@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2009-2010 Brazil
+/* Copyright(C) 2009-2011 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -37,10 +37,11 @@ typedef struct
 static int
 compute_diff_bit(uint8_t *geo_key1, uint8_t *geo_key2)
 {
-  int i, j, diff_bit = 8;
+  int i, j, diff_bit = 0;
 
   for (i = 0; i < sizeof(grn_geo_point); i++) {
     if (geo_key1[i] != geo_key2[i]) {
+      diff_bit = 8;
       for (j = 0; j < 8; j++) {
         if ((geo_key1[i] & (1 << (7 - j))) != (geo_key2[i] & (1 << (7 - j)))) {
           diff_bit = j;
@@ -171,6 +172,7 @@ grn_geo_table_sort_detect_far_point(grn_ctx *ctx, grn_obj *table, grn_obj *index
       }
       if (diff_bit_current < diff_bit_prev && *diff_bit > diff_bit_current) {
         if (i == n) {
+          grn_ii_cursor_close(ctx, ic);
           break;
         }
         *diff_bit = diff_bit_current;
@@ -695,6 +697,46 @@ grn_geo_search_in_rectangle(grn_ctx *ctx, grn_obj *obj, grn_obj **args, int narg
       goto exit;
     }
 
+    if (geo_point1->latitude >= GRN_GEO_MAX_LATITUDE) {
+      ERR(GRN_INVALID_ARGUMENT,
+          "geo_in_rectangle(): geo point1's latitude is too big: <%d>(max:%d): "
+          "(%d,%d) (%d,%d)",
+          GRN_GEO_MAX_LATITUDE, geo_point1->latitude,
+          geo_point1->latitude, geo_point1->longitude,
+          geo_point2->latitude, geo_point2->longitude);
+      goto exit;
+    }
+
+    if (geo_point1->longitude >= GRN_GEO_MAX_LONGITUDE) {
+      ERR(GRN_INVALID_ARGUMENT,
+          "geo_in_rectangle(): geo point1's longitude is too big: <%d>(max:%d): "
+          "(%d,%d) (%d,%d)",
+          GRN_GEO_MAX_LONGITUDE, geo_point1->longitude,
+          geo_point1->latitude, geo_point1->longitude,
+          geo_point2->latitude, geo_point2->longitude);
+      goto exit;
+    }
+
+    if (geo_point2->latitude >= GRN_GEO_MAX_LATITUDE) {
+      ERR(GRN_INVALID_ARGUMENT,
+          "geo_in_rectangle(): geo point2's latitude is too big: <%d>(max:%d): "
+          "(%d,%d) (%d,%d)",
+          GRN_GEO_MAX_LATITUDE, geo_point2->latitude,
+          geo_point1->latitude, geo_point1->longitude,
+          geo_point2->latitude, geo_point2->longitude);
+      goto exit;
+    }
+
+    if (geo_point2->longitude >= GRN_GEO_MAX_LONGITUDE) {
+      ERR(GRN_INVALID_ARGUMENT,
+          "geo_in_rectangle(): geo point2's longitude is too big: <%d>(max:%d): "
+          "(%d,%d) (%d,%d)",
+          GRN_GEO_MAX_LONGITUDE, geo_point2->longitude,
+          geo_point1->latitude, geo_point1->longitude,
+          geo_point2->latitude, geo_point2->longitude);
+      goto exit;
+    }
+
     latitude_distance = geo_point1->latitude - geo_point2->latitude;
     longitude_distance = geo_point2->longitude - geo_point1->longitude;
     if (latitude_distance > longitude_distance) {
@@ -753,6 +795,9 @@ grn_geo_search_in_rectangle(grn_ctx *ctx, grn_obj *obj, grn_obj **args, int narg
                                  NULL, 0,
                                  0, -1,
                                  GRN_CURSOR_PREFIX|GRN_CURSOR_SIZE_BY_BIT);
+#ifdef GEO_DEBUG
+      printf("i:                   %10d\n", i);
+#endif
       inspect_mesh(ctx, &geo_point_base, diff_bit, (i - start) / distance);
       if (tc) {
         grn_id tid;
