@@ -15,6 +15,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <stdint.h>
 #include <stdarg.h>
@@ -27,6 +28,8 @@
 
 #include "util.h"
 
+#define DEFAULT_THRESHOLD 100
+
 int
 print_error(const char *format, ...)
 {
@@ -96,7 +99,9 @@ parse_keyval(struct evkeyvalq *get_args,
              const char **client_id, const char **target_name,
              const char **learn_target_name,
              const char **callback,
-             uint64_t *millisec)
+             uint64_t *millisec,
+             int *threshold,
+             int *limit)
 {
   struct evkeyval *get;
 
@@ -107,6 +112,8 @@ parse_keyval(struct evkeyvalq *get_args,
   if (learn_target_name) { *learn_target_name = NULL; }
   if (callback) { *callback = NULL; }
   if (millisec) { *millisec = 0; }
+  if (threshold) { *threshold = DEFAULT_THRESHOLD; }
+  if (limit) { *limit = -1; }
 
   TAILQ_FOREACH(get, get_args, next) {
     switch(get->key[0]) {
@@ -147,6 +154,16 @@ parse_keyval(struct evkeyvalq *get_args,
         *learn_target_name = get->value;
       }
       break;
+    case 'h':
+      if (threshold) {
+        *threshold = atoi(get->value);
+      }
+      break;
+    case 'm':
+      if (limit) {
+        *limit = atoi(get->value);
+      }
+      break;
     default:
       break;
     }
