@@ -28,6 +28,7 @@ void attributes_bool(void);
 void data_bool(void);
 void test_bool(gconstpointer data);
 void test_int32_key(void);
+void test_time_float(void);
 void data_null(void);
 void test_null(gconstpointer data);
 void test_index_geo_point(void);
@@ -80,6 +81,7 @@ void
 cut_teardown(void)
 {
   if (context) {
+    grn_obj_close(context, database);
     grn_ctx_fin(context);
     g_free(context);
   }
@@ -196,6 +198,24 @@ test_int32_key(void)
                           send_command("select Students"));
 }
 
+void
+test_time_float(void)
+{
+  assert_send_command("table_create Logs TABLE_NO_KEY");
+  assert_send_command("column_create Logs time_stamp COLUMN_SCALAR Time");
+  cut_assert_equal_string("1",
+                          send_command("load --table Logs\n"
+                                       "[{\"time_stamp\": 1295851581.41798}]"));
+  cut_assert_equal_string("[[[1],"
+                          "["
+                          "[\"_id\",\"UInt32\"],"
+                          "[\"time_stamp\",\"Time\"]"
+                          "],"
+                          "[1,1295851581.41798]"
+                          "]]",
+                          send_command("select Logs"));
+}
+
 void
 data_null(void)
 {
@@ -435,17 +455,14 @@ test_invalid_start_with_symbol(void)
 void
 test_no_key_table_without_columns(void)
 {
-  cut_omit("crashed!!!");
   assert_send_command("table_create Numbers TABLE_NO_KEY");
-  cut_assert_equal_string("0",
-                          send_command("load --table Numbers [\n"
-                                       "[1],\n"
-                                       "[2],\n"
-                                       "[3]\n"
-                                       "]"));
-  cut_assert_equal_string("[[[0],"
-                          "[[\"_id\",\"Int32\"]],"
-                          "]]",
-                          send_command("select Numbers"));
-
+  grn_test_assert_send_command_error(context,
+                                     GRN_INVALID_ARGUMENT,
+                                     "column name must be string: <1>",
+                                     "load --table Numbers\n"
+                                     "[\n"
+                                     "[1],\n"
+                                     "[2],\n"
+                                     "[3]\n"
+                                     "]");
 }
