@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2; coding: utf-8 -*- */
 /*
-  Copyright (C) 2009-2010  Kouhei Sutou <kou@clear-code.com>
+  Copyright (C) 2009-2011  Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -83,10 +83,9 @@ cut_setup(void)
 void
 cut_teardown(void)
 {
-  if (context) {
-    grn_ctx_fin(context);
-    g_free(context);
-  }
+  grn_obj_close(context, database);
+  grn_ctx_fin(context);
+  g_free(context);
   teardown_grn_logger(logger);
   cut_remove_path(tmp_directory, NULL);
 }
@@ -99,6 +98,7 @@ test_array_set_data(void)
   gchar value[] = "sample value";
   grn_obj *record_value;
   grn_obj *retrieved_record_value;
+  const gchar *dupped_retrieved_record_value;
   gchar *value_type_name = "value_type";
   grn_obj *value_type;
 
@@ -114,9 +114,13 @@ test_array_set_data(void)
   grn_bulk_write(context, record_value, value, sizeof(value));
   grn_test_assert(grn_obj_set_value(context, table, record_id,
                                     record_value, GRN_OBJ_SET));
+  grn_obj_unlink(context, record_value);
 
   retrieved_record_value = grn_obj_get_value(context, table, record_id, NULL);
-  cut_assert_equal_string(value, GRN_BULK_HEAD(retrieved_record_value));
+  dupped_retrieved_record_value =
+    cut_take_strdup(GRN_BULK_HEAD(retrieved_record_value));
+  grn_obj_unlink(context, retrieved_record_value);
+  cut_assert_equal_string(value, dupped_retrieved_record_value);
 }
 
 void
@@ -428,7 +432,7 @@ test_array_truncate(void)
   gchar *value_type_name = "value_type";
   grn_obj *value_type;
 
-  cut_omit("grn_table_truncate() is not implemented.");
+  cut_omit("grn_table_truncate() is still buggy.");
 
   value_type = grn_type_create(context,
                                value_type_name, strlen(value_type_name),
