@@ -642,6 +642,9 @@ grn_test_send_command(grn_ctx *context, const gchar *command)
     int flags = 0;
 
     send_id = grn_ctx_send(context, *lines, strlen(*lines), 0);
+    grn_test_assert_context(context,
+                            cut_message("<%s>:<%s>:<%s>",
+                                        *lines, command, result->str));
     receive_id = grn_ctx_recv(context, &command_result, &command_result_length,
                               &flags);
     cut_assert_equal_uint(send_id, receive_id);
@@ -737,10 +740,10 @@ grn_test_coordinate_in_milliseconds(gdouble coordinate_in_degree)
 {
   gint coordinate_in_milliseconds = 0;
   gint accuracy = 10000000;
-  gint decimal_number;
+  glong decimal_number;
 
   coordinate_in_milliseconds += (gint)coordinate_in_degree * 60 * 60 * 1000;
-  decimal_number = ((gint)(coordinate_in_degree * accuracy) % accuracy) * 60;
+  decimal_number = ((glong)(coordinate_in_degree * accuracy) % accuracy) * 60;
   coordinate_in_milliseconds += decimal_number / accuracy * 60 * 1000;
   coordinate_in_milliseconds += decimal_number % accuracy * 60 / 10000;
 
